@@ -1,8 +1,8 @@
-use std::{panic::panic_any, time::Instant};
+use std::{f32::consts::PI, panic::panic_any, time::Instant};
 
 extern crate dubins_paths;
 
-use dubins_paths::{DubinsPathType, path_sample_many, shortest_path, shortest_path_in};
+use dubins_paths::{DubinsPath, DubinsPathType};
 pub const MAX_TURN_RADIUS: f32 = 1. / 0.00076;
 
 #[test]
@@ -14,9 +14,9 @@ fn fast_shortest_csc_path() {
         let start = Instant::now();
 
         let q0 = [2000., 2000., 0.];
-        let q1 = [0., 0., 3.14];
+        let q1 = [0., 0., PI];
 
-        if let Err(err) = shortest_path_in(q0, q1, MAX_TURN_RADIUS, &DubinsPathType::CCC) {
+        if let Err(err) = DubinsPath::shortest_in(q0, q1, MAX_TURN_RADIUS, &DubinsPathType::CCC) {
             panic_any(err);
         }
 
@@ -39,9 +39,9 @@ fn fast_shortest_ccc_path() {
         let start = Instant::now();
 
         let q0 = [2000., 2000., 0.];
-        let q1 = [0., 0., 3.14];
+        let q1 = [0., 0., PI];
 
-        if let Err(err) = shortest_path_in(q0, q1, MAX_TURN_RADIUS, &DubinsPathType::CSC) {
+        if let Err(err) = DubinsPath::shortest_in(q0, q1, MAX_TURN_RADIUS, &DubinsPathType::CSC) {
             panic_any(err);
         }
 
@@ -64,9 +64,9 @@ fn fast_shortest_path() {
         let start = Instant::now();
 
         let q0 = [2000., 2000., 0.];
-        let q1 = [0., 0., 3.14];
+        let q1 = [0., 0., PI];
 
-        if let Err(err) = shortest_path(q0, q1, MAX_TURN_RADIUS) {
+        if let Err(err) = DubinsPath::shortest_from(q0, q1, MAX_TURN_RADIUS) {
             panic_any(err);
         }
 
@@ -86,9 +86,9 @@ fn fast_many_sample() {
     let mut times = Vec::new();
 
     let q0 = [2000., 2000., 0.];
-    let q1 = [0., 0., 3.14];
+    let q1 = [0., 0., PI];
 
-    let path = match shortest_path(q0, q1, MAX_TURN_RADIUS) {
+    let path = match DubinsPath::shortest_from(q0, q1, MAX_TURN_RADIUS) {
         Ok(p) => p,
         Err(err) => panic_any(err),
     };
@@ -96,9 +96,7 @@ fn fast_many_sample() {
     for _ in 0..runs {
         let start = Instant::now();
 
-        if let Err(err) = path_sample_many(&path, 20.) {
-            panic_any(err);
-        }
+        path.sample_many(20.);
 
         times.push(start.elapsed().as_secs_f32());
     }
